@@ -344,7 +344,7 @@ class ldapUser(_error):
         for dict_attr in list_user_attr:
             ldap_attr = convert_dict[dict_attr][1]
             if ldap_attr in search_user[0][0][1]:
-                dict_out[dict_attr] = search_user[0][0][1][ldap_attr][0]
+                dict_out[dict_attr] = search_user[0][0][1][ldap_attr][0].decode("UTF-8")
             else:
                 dict_out[dict_attr] = ""
             if dict_attr == 'uid':
@@ -365,7 +365,7 @@ class ldapUser(_error):
                     if search_group:
                         data = search_group[0][0][1]
                         if ldap_attr in data:
-                            dict_out[dict_attr] = data[ldap_attr][0]
+                            dict_out[dict_attr] = data[ldap_attr][0].decode("UTF-8")
                         else:
                             dict_out[dict_attr] = ""
                     else:
@@ -379,7 +379,7 @@ class ldapUser(_error):
                             ["cn", "gidNumber"])
                         if search_group:
                             user_groups_data.extend(
-                                [(x[0][1]["cn"][0], x[0][1]["gidNumber"][0])
+                                [(x[0][1]["cn"][0].decode("UTF-8"), x[0][1]["gidNumber"][0].decode("UTF-8"))
                                  for x in search_group])
                     dict_out[dict_attr] = user_groups_data
         if uid and gid:
