@@ -24,15 +24,10 @@ from random import choice
 from base64 import encodebytes as _b64enc
 
 b64encode = lambda x: _b64enc(x).rstrip()
-# try:
-#     from smbpasswd import lmhash, nthash
-# except ImportError:
-#     lmhash, nthash = None, None
 import calculate.contrib
-from passlib.hash import nthash, lmhash
+from passlib.hash import nthash, lmhash, sha256_crypt, grub_pbkdf2_sha512
 from .cl_print import color_print
 from . import cl_overriding
-from calculate.contrib.passlib.hash import sha256_crypt, grub_pbkdf2_sha512
 
 from .cl_lang import setLocalTranslate
 
@@ -61,7 +56,7 @@ class encrypt(color_print):
 
     def __GenCryptSalt__(self, len=2):
         """Генерация соли для хеширования пароля (CRYPT)"""
-        chars = string.letters + string.digits + "./"
+        chars = string.ascii_letters + string.digits + "./"
         salt = ""
         for i in range(len):
             salt = salt + choice(chars)
@@ -79,21 +74,18 @@ class encrypt(color_print):
                             _("empty password"))
             return False
 
-        if isinstance(password, str):
-            password = password.encode("UTF-8")
-
         if SecHashAlg == "plain":
             hash_pwd = password
 
         elif SecHashAlg == "md5":
-            h = hashlib.md5(password)
-            hash_pwd = "{MD5}" + b64encode(h.digest())
+            h = hashlib.md5(password.encode("UTF-8"))
+            hash_pwd = "{MD5}" + b64encode(h.digest()).decode("UTF-8")
 
         elif SecHashAlg == "smd5":
             salt = os.urandom(4)
-            h = hashlib.md5(password)
+            h = hashlib.md5(password.encode("UTF-8"))
             h.update(salt)
-            hash_pwd = "{SMD5}" + b64encode(h.digest() + salt)
+            hash_pwd = "{SMD5}" + b64encode(h.digest() + salt).decode("UTF-8")
 
         elif SecHashAlg == "shadow_ssha512":
             salt = self.__GenCryptSalt__(8)
@@ -112,19 +104,19 @@ class encrypt(color_print):
             hash_pwd = "{CRYPT}" + crypt.crypt(password, salt)
 
         elif SecHashAlg == "sha":
-            h = hashlib.sha1(password)
-            hash_pwd = "{SHA}" + b64encode(h.digest())
+            h = hashlib.sha1(password.encode("UTF-8"))
+            hash_pwd = "{SHA}" + b64encode(h.digest()).decode("UTF-8")
 
         elif SecHashAlg == "ssha":
             salt = os.urandom(4)
-            h = hashlib.sha1(password)
+            h = hashlib.sha1(password.encode("UTF-8"))
             h.update(salt)
-            hash_pwd = "{SSHA}" + b64encode(h.digest() + salt)
+            hash_pwd = "{SSHA}" + b64encode(h.digest() + salt).decode("UTF-8")
 
         elif SecHashAlg == "lm":
-            hash_pwd = lmhash(password)
+            hash_pwd = lmhash.hash(password).upper()
         elif SecHashAlg == "nt":
-            hash_pwd = nthash(password)
+            hash_pwd = nthash.hash(password).upper()
         else:
             if SecHashAlg in ("lm", "nt"):
                 self.printERROR(
