@@ -182,18 +182,13 @@ class BinhostsBase(Cachable):
                             self.level = int(cp["update"]["level"])
 
                             #DEBUG
-                            # if not "https://mirror.calculate-linux.org/migrate/" in self.host:
-                            #     hosts_mod_levels = {
-
-                            #           "https://ftp.acc.umu.se/mirror/calculate-linux.org" : 1,
-                            #           
-                            #      }
-
-
-                            #     for host in hosts_mod_levels:
-                            #         if host in self.host: 
-                            #             self.level = hosts_mod_levels[host]
-                            #             break
+                            hosts_mod_levels_override = {
+                                    # "https://ftp.acc.umu.se/mirror/calculate-linux.org" : 1,
+                                    }
+                            for host in hosts_mod_levels_override:
+                                if host in self.host: 
+                                    self.level = hosts_mod_levels_override[host]
+                                    break
 
 
                         else:
