@@ -13,7 +13,6 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-from __future__ import absolute_import
 from .printing import Print
 from .palette import TextState
 from .info import Terminal
@@ -27,7 +26,8 @@ from .output import XmlOutput, ColorTerminal16Output, TerminalPositionOutput, \
 
 def convert_console_to_xml(s):
     """Преобразовать вывод консоли в xml для внутреннего использования"""
-    return ConsoleCodes256Converter(output=XmlOutput()).transform(s)
+    tmp = ConsoleCodes256Converter(output=XmlOutput()).transform(s)
+    return  tmp
 
 
 def get_color_print():
